@@ -1,12 +1,20 @@
-from nonebot import require
+from nonebot import require, get_driver
 from nonebot.log import logger
 from nonebot.plugin import PluginMetadata
-from .repo_activity import check_and_notify_updates
+from .repo_activity import check_repo_updates, validate_github_token
 from .config import config
-from .group_commands import add_group_repo_data, remove_group_repo_data
-from .db_action import init_database, load_groups
+# from .group_commands import add_group_repo_data, remove_group_repo_data
+from .db_action import (
+    init_database,
+    load_groups,
+    add_group_repo_data,
+    remove_group_repo_data
+)
+from .commands import repo_group
+from .config import Config
 
-__version__ = ver = "0.1.3"
+__version__ = ver = "0.1.6.1"
+cmd_group = repo_group
 
 __plugin_meta__ = PluginMetadata(
     name="github_release_notifier",
@@ -17,11 +25,18 @@ __plugin_meta__ = PluginMetadata(
     ),
     type='application',
     usage="github repo events auto forward|自动转发github repo事件",
-    homepage="https://github.com/HTony03/nonebot_plugin_github_release_notifier",
+    homepage=(
+        "https://github.com/HTony03/nonebot_plugin_github_release_notifier"
+    ),
+    config=Config(),
     supported_adapters={"~onebot.v11"},
     extra={},
 )
-logger.info(f'initing nonebot_plugin_github_release_notifier version: {ver}')
+logger.info(
+    f"Initializing nonebot_plugin_github_release_notifier version: {ver}"
+)
+
+# TODO: use pic to show the usage
 
 # Scheduler for periodic tasks
 scheduler = require("nonebot_plugin_apscheduler").scheduler
@@ -83,8 +98,19 @@ def refresh_data_from_db():
     group_repo_dict = load_groups()
 
 
+# Asynchronous initialization
+async def plugin_init():
+    """Run asynchronous initialization tasks."""
+    await validate_github_token()
+
+
+# Register the initialization function to run when the bot starts
+driver = get_driver()
+driver.on_startup(plugin_init)
+
+
 @scheduler.scheduled_job("cron", minute="*/5")
 # Trigger every 5 minutes (:00, :05, :10, ...)
 async def _():
     """Check for all repos and notify groups."""
-    await check_and_notify_updates()
+    await check_repo_updates()
